<?php
/*
Plugin Name: PDF Bridge
Plugin URI: 
Description: This is a plugin for developers. It lets you convert your HTML content to PDF and then do whatever you want with it (save it as file or output it). Uses the <a href="http://www.mpdf1.com/mpdf/index.php" target="_blank">MPDF library</a>
Author: Kiboko Labs
Version: 1.4.3
Author URI: http://calendarscripts.info/
License: GPLv2 or later
*/

define( 'PDF_BRIDGE_PATH', dirname( __FILE__ ) );
// register_activation_hook(__FILE__, 'pdf_bridge_init');

add_action('init', 'pdf_bridge_init');

function pdf_bridge_init() {
	global $wpdb;

	add_filter('pdf-bridge-convert', 'pdfbridge_html2pdf', 10, 2);
	add_action('template_redirect', 'pdf_bridge_test');
	add_action('watupro-certificate-pdf-settings', 'pdf_bridge_certificate_settings');
	add_action('watupro-quiz-pdf-settings', 'pdf_bridge_quiz_settings');
	add_action('watupro-certificate-saved', 'pdf_bridge_certificate_saved');
	add_action('namaste-certificate-pdf-settings', 'pdf_bridge_namaste_certificate_settings');
	add_action('namaste-certificate-saved', 'pdf_bridge_namaste_certificate_saved');
}

// param $settings is optional array of PDF settings, same like in WatuPRO or Namaste
// $pdf_settings is optional array that can be passed to the function instead of it reading it from $content
function pdfbridge_html2pdf($content, $pdf_settings = null) {	
	if(!class_exists('mPDF')) include(PDF_BRIDGE_PATH.'/lib/mpdf/mpdf.php');
	
	// extract the ID from contents
	if(strstr($content, '-watupro-certificate-id-')) {
		$parts = explode('-watupro-certificate-id-', $content);
		$cid = $parts[1];
		$settings = get_option('watupro_certificates_pdf');
	}	
	if(strstr($content, '-namaste-certificate-id-')) {
		$parts = explode('-namaste-certificate-id-', $content);
		$cid = $parts[1];
		$settings = get_option('namaste_certificates_pdf');
	}	
	
   $pdf_settings = @$settings[$cid];
   $paper_size = empty($pdf_settings['paper_size']) ? 'Letter' : $pdf_settings['paper_size'];
   $orientation = @$pdf_settings['orientation'];
	
	$mpdf = new mPDF('s', $paper_size.$orientation);
	$mpdf->showImageErrors = true;
	
	$content = mb_convert_encoding($content, 'UTF-8', 'UTF-8');
   
   if(!empty($pdf_settings['background_image'])) {
      $content = '<style type="text/css">
         body {background-image:url('.$pdf_settings['background_image'].'); background-image-resize:'.intval($pdf_settings['background_resize']).'}
       </style>'."\n".$content;
   }	
   
   $file_name = "certificate-".@$_POST['watupro_current_taking_id'].'.pdf';
   
   //  force download with dynamic file data from other plugins
   if(!empty($_GET['download_file_name'])) {   
   	$_GET['download_file_name'] = sanitize_file_name($_GET['download_file_name']);
   	if(empty($pdf_settings) or !is_array($pdf_settings)) $pdf_settings = array();
   	$pdf_settings['file_name'] = $file_name = sanitize_text_field($_GET['download_file_name']);
   	$pdf_settings['force_download'] = 1;
   }   
   
   // add stylesheets
   if(!empty($pdf_settings['stylesheets']) and is_array($pdf_settings['stylesheets'])) {
   	foreach($pdf_settings['stylesheets'] as $css) {
   		$stylesheet = @file_get_contents($css);
   		if(!empty($stylesheet)) $mpdf->WriteHTML($stylesheet, 1);
   	}
   }
	
	$mpdf->WriteHTML($content);
	if(!empty($_GET['certificate_as_attachment'])) $pdf_settings['certificate_as_attachment'] = $_GET['certificate_as_attachment'];
	if(!empty($pdf_settings['force_download']) and empty($pdf_settings['certificate_as_attachment'])) $mpdf->Output($pdf_settings['file_name'], 'D');
	elseif(!empty($pdf_settings['certificate_as_attachment'])) $mpdf->Output(WP_CONTENT_DIR . "/uploads/" . $file_name, 'F');
	else $mpdf->Output(); 
}

// allow to test the plugin installation with a very simple output
// by passing param pdf-bridge-test=1 in the URL
function pdf_bridge_test() {
	
	if(!empty($_GET['pdf-bridge-test'])) {
		$content = "<h1>Very simple test</h1><p>Hello PDF!</p>";
		$pdf =  pdfbridge_html2pdf($content);
		die($pdf);
	}
}

// displays extra options in the add/edit certificate form
function pdf_bridge_certificate_settings($cid = 0, $plugin = 'watupro') {
  // get the current certificate settings
  $settings = ($plugin == 'watupro') ? get_option('watupro_certificates_pdf') : get_option('namaste_certificates_pdf'); 
  $pdf_settings = @$settings[$cid];
  
  // paper sizes
  $paper_sizes = array('Letter', 'A5', 'A4', 'A3', 'A2', 'A1', 'A0', 'B4', 'B3', 'B2', 'B1', 'B0');
 	
 	include(PDF_BRIDGE_PATH."/views/certificate-settings.html.php");  	
}

// displays extra options in final screen tab in WatuPRO
function pdf_bridge_quiz_settings($pdf_settings = null) {
  // paper sizes
  $paper_sizes = array('Letter', 'A5', 'A4', 'A3', 'A2', 'A1', 'A0', 'B4', 'B3', 'B2', 'B1', 'B0');
  $quiz = true;
 	
 	include(PDF_BRIDGE_PATH."/views/certificate-settings.html.php");  	
}

// same but in Namaste! LMS
function pdf_bridge_namaste_certificate_settings($cid = 0) {
	pdf_bridge_certificate_settings($cid, 'namaste');
}

// when saving a certificate store the settings
function pdf_bridge_certificate_saved($cid, $plugin = 'watupro') {
	$option_name = ($plugin == 'watupro') ? 'watupro_certificates_pdf' : 'namaste_certificates_pdf';
	$settings = get_option($option_name);
	
	if(!empty($_POST['pdf_bridge_file_name']) and !preg_match("/\.pdf$/i", $_POST['pdf_bridge_file_name']))	 $_POST['pdf_bridge_file_name'] .= ".pdf";
	
	$settings[$cid] = array('paper_size' => sanitize_text_field($_POST['pdf_bridge_paper_size']), 
		'orientation' => sanitize_text_field($_POST['pdf_bridge_orientation']), 'force_download' => intval(@$_POST['pdf_bridge_force_download']),
		'file_name' => sanitize_text_field($_POST['pdf_bridge_file_name']), 
		'background_image' => esc_url_raw($_POST['pdf_bridge_background_image']),
		'background_resize' => intval($_POST['pdf_bridge_background_resize']));
	update_option($option_name, $settings);
}

// same but in Namaste! LMS
function pdf_bridge_namaste_certificate_saved($cid) {
	pdf_bridge_certificate_saved($cid, 'namaste'); 
}